@@ -9,13 +9,14 @@
  See the file COPYING for the full license text.
 */
 
-#ifndef __KATZE__
-#define __KATZE__
+#ifndef __KATZE_H__
+#define __KATZE_H__
 
 #include "katze-throbber.h"
 #include "katze-utils.h"
 #include "katze-item.h"
-#include "katze-weblist.h"
+#include "katze-list.h"
+#include "katze-array.h"
 #include "katze-xbel.h"
 
 #endif /* __KATZE_H__ */
