@@ -23,6 +23,7 @@ struct _MidoriLocationAction
     GtkAction parent_instance;
 
     gchar* uri;
+    gdouble progress;
 };
 
 struct _MidoriLocationActionClass
@@ -36,6 +37,7 @@ enum
 {
     PROP_0,
 
+    PROP_PROGRESS,
     PROP_SECONDARY_ICON
 };
 
@@ -74,6 +76,42 @@ static void
 midori_location_action_disconnect_proxy (GtkAction* action,
                                          GtkWidget* proxy);
 
+static void
+midori_cclosure_marshal_VOID__STRING_BOOLEAN (GClosure*     closure,
+                                              GValue*       return_value,
+                                              guint         n_param_values,
+                                              const GValue* param_values,
+                                              gpointer      invocation_hint,
+                                              gpointer      marshal_data)
+{
+    typedef void(*GMarshalFunc_VOID__STRING_BOOLEAN) (gpointer      data1,
+                                                      const gchar*  arg_1,
+                                                      gboolean      arg_2,
+                                                      gpointer      data2);
+    register GMarshalFunc_VOID__STRING_BOOLEAN callback;
+    register GCClosure* cc = (GCClosure*) closure;
+    register gpointer data1, data2;
+
+    g_return_if_fail (n_param_values == 3);
+
+    if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+        data1 = closure->data;
+        data2 = g_value_peek_pointer (param_values + 0);
+    }
+    else
+    {
+        data1 = g_value_peek_pointer (param_values + 0);
+        data2 = closure->data;
+    }
+    callback = (GMarshalFunc_VOID__STRING_BOOLEAN) (marshal_data
+        ? marshal_data : cc->callback);
+    callback (data1,
+              g_value_get_string (param_values + 1),
+              g_value_get_boolean (param_values + 2),
+              data2);
+}
+
 static void
 midori_location_action_class_init (MidoriLocationActionClass* class)
 {
@@ -124,9 +162,10 @@ midori_location_action_class_init (MidoriLocationActionClass* class)
                                         0,
                                         0,
                                         NULL,
-                                        g_cclosure_marshal_VOID__STRING,
-                                        G_TYPE_NONE, 1,
-                                        G_TYPE_STRING);
+                                        midori_cclosure_marshal_VOID__STRING_BOOLEAN,
+                                        G_TYPE_NONE, 2,
+                                        G_TYPE_STRING,
+                                        G_TYPE_BOOLEAN);
 
     gobject_class = G_OBJECT_CLASS (class);
     gobject_class->finalize = midori_location_action_finalize;
@@ -138,11 +177,20 @@ midori_location_action_class_init (MidoriLocationActionClass* class)
     action_class->connect_proxy = midori_location_action_connect_proxy;
     action_class->disconnect_proxy = midori_location_action_disconnect_proxy;
 
+    g_object_class_install_property (gobject_class,
+                                     PROP_PROGRESS,
+                                     g_param_spec_double (
+                                     "progress",
+                                     _("Progress"),
+                                     _("The current progress of the action"),
+                                     0.0, 1.0, 0.0,
+                                     G_PARAM_WRITABLE));
+
     g_object_class_install_property (gobject_class,
                                      PROP_SECONDARY_ICON,
                                      g_param_spec_string (
                                      "secondary-icon",
-                                     "Secondary",
+                                     _("Secondary"),
                                      _("The stock ID of the secondary icon"),
                                      NULL,
                                      G_PARAM_WRITABLE));
@@ -152,6 +200,7 @@ static void
 midori_location_action_init (MidoriLocationAction* location_action)
 {
     location_action->uri = NULL;
+    location_action->progress = 0.0;
 }
 
 static void
@@ -174,6 +223,12 @@ midori_location_action_set_property (GObject*      object,
 
     switch (prop_id)
     {
+    case PROP_PROGRESS:
+    {
+        midori_location_action_set_progress (location_action,
+            g_value_get_double (value));
+        break;
+    }
     case PROP_SECONDARY_ICON:
     {
         midori_location_action_set_secondary_icon (location_action,
@@ -223,6 +278,8 @@ midori_location_action_create_tool_item (GtkAction* action)
     toolitem = GTK_WIDGET (gtk_tool_item_new ());
     gtk_tool_item_set_expand (GTK_TOOL_ITEM (toolitem), TRUE);
     entry = midori_location_entry_new ();
+    midori_location_entry_set_progress (MIDORI_LOCATION_ENTRY (entry),
+        MIDORI_LOCATION_ACTION (action)->progress);
     gtk_icon_entry_set_icon_highlight (GTK_ICON_ENTRY (
         gtk_bin_get_child (GTK_BIN (entry))),
         GTK_ICON_ENTRY_SECONDARY, TRUE);
@@ -265,7 +322,8 @@ midori_location_action_key_press_event_cb (GtkWidget*   widget,
     {
         if ((uri = gtk_entry_get_text (GTK_ENTRY (widget))))
         {
-            g_signal_emit (action, signals[SUBMIT_URI], 0, uri);
+            g_signal_emit (action, signals[SUBMIT_URI], 0, uri,
+                (event->state & GDK_MOD1_MASK) ? TRUE : FALSE);
             return TRUE;
         }
     }
@@ -355,7 +413,6 @@ midori_location_action_set_uri (MidoriLocationAction* location_action,
     g_return_if_fail (MIDORI_IS_LOCATION_ACTION (location_action));
     g_return_if_fail (uri != NULL);
 
-
     katze_assign (location_action->uri, g_strdup (uri));
 
     proxies = gtk_action_get_proxies (GTK_ACTION (location_action));
@@ -478,6 +535,42 @@ midori_location_action_set_title_for_uri (MidoriLocationAction* location_action,
     while ((proxies = g_slist_next (proxies)));
 }
 
+gdouble
+midori_location_action_get_progress (MidoriLocationAction* location_action)
+{
+    g_return_val_if_fail (MIDORI_IS_LOCATION_ACTION (location_action), 0.0);
+
+    return location_action->progress;
+}
+
+void
+midori_location_action_set_progress (MidoriLocationAction* location_action,
+                                     gdouble               progress)
+{
+    GSList* proxies;
+    GtkWidget* alignment;
+    GtkWidget* entry;
+
+    g_return_if_fail (MIDORI_IS_LOCATION_ACTION (location_action));
+
+    location_action->progress = CLAMP (progress, 0.0, 1.0);
+
+    proxies = gtk_action_get_proxies (GTK_ACTION (location_action));
+    if (!proxies)
+        return;
+
+    do
+    if (GTK_IS_TOOL_ITEM (proxies->data))
+    {
+        alignment = gtk_bin_get_child (GTK_BIN (proxies->data));
+        entry = gtk_bin_get_child (GTK_BIN (alignment));
+
+        midori_location_entry_set_progress (MIDORI_LOCATION_ENTRY (entry),
+                                            location_action->progress);
+    }
+    while ((proxies = g_slist_next (proxies)));
+}
+
 void
 midori_location_action_set_secondary_icon (MidoriLocationAction* location_action,
                                            const gchar*          stock_id)
