@@ -20,6 +20,7 @@
     #include <unistd.h>
 #endif
 #include <string.h>
+
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <glib/gprintf.h>
@@ -80,8 +81,8 @@ sokoke_spawn_program (const gchar* command,
 }
 
 gchar*
-sokoke_magic_uri (const gchar*   uri,
-                  MidoriWebList* search_engines)
+sokoke_magic_uri (const gchar* uri,
+                  KatzeArray*  search_engines)
 {
     gchar* current_dir;
     gchar* result;
@@ -92,7 +93,7 @@ sokoke_magic_uri (const gchar*   uri,
 
     g_return_val_if_fail (uri, NULL);
     if (search_engines)
-        g_return_val_if_fail (MIDORI_IS_WEB_LIST (search_engines), NULL);
+        g_return_val_if_fail (katze_array_is_a (search_engines, KATZE_TYPE_ITEM), NULL);
 
     /* Add file:// if we have a local path */
     if (g_path_is_absolute (uri))
@@ -122,7 +123,7 @@ sokoke_magic_uri (const gchar*   uri,
         parts = g_strsplit (uri, " ", 2);
         if (parts[0] && parts[1])
         {
-            item = midori_web_list_find_token (search_engines, parts[0]);
+            item = katze_array_find_token (search_engines, parts[0]);
             if (item)
                 search_uri = katze_item_get_uri (item);
         }
@@ -610,7 +611,7 @@ sokoke_object_get_boolean (gpointer     object,
  * @action: a #GtkAction
  *
  * Creates a menu item from an action, just like
- * gtk_action_create_menu_item() but it won't
+ * gtk_action_create_menu_item(), but it won't
  * display an accelerator.
  *
  * Return value: a new #GtkMenuItem
@@ -620,31 +621,43 @@ sokoke_action_create_popup_menu_item (GtkAction* action)
 {
     GtkWidget* menuitem;
 
-    menuitem = gtk_image_menu_item_new_with_mnemonic ("");
+    g_return_val_if_fail (GTK_IS_ACTION (action), NULL);
+
+    menuitem = gtk_image_menu_item_new ();
     gtk_action_connect_proxy (action, menuitem);
 
     return menuitem;
 }
 
+/**
+ * sokoke_tree_view_get_selected_iter:
+ * @tree_view: a #GtkTreeView
+ * @model: a pointer to store the model, or %NULL
+ * @iter: a pointer to store the iter, or %NULL
+ *
+ * Determines whether there is a selection in the tree view
+ * and sets the @iter to the current selection.
+ *
+ * If there is a selection and @model is not %NULL, it is
+ * set to the model, mainly for convenience.
+ *
+ * Either @model or @iter or both can be %NULL in which case
+ * no value will be assigned in any case.
+ *
+ * Return value: %TRUE if there is a selection
+ **/
 gboolean
-sokoke_gio_supports_http (void)
+sokoke_tree_view_get_selected_iter (GtkTreeView*   tree_view,
+                                    GtkTreeModel** model,
+                                    GtkTreeIter*   iter)
 {
-    #if HAVE_GIO
-    static gboolean supports_http;
-    static gboolean tested;
-    const gchar* const* schemes = g_vfs_get_supported_uri_schemes (g_vfs_get_default ());
+    GtkTreeSelection* selection;
 
-    if (tested)
-        return supports_http;
-    while (*schemes)
-    {
-        if (!strcmp (*schemes, "http"))
-            supports_http = TRUE;
-        schemes++;
-    }
-    tested = TRUE;
-    return supports_http;
-    #else
+    g_return_val_if_fail (GTK_IS_TREE_VIEW (tree_view), FALSE);
+
+    selection = gtk_tree_view_get_selection (tree_view);
+    if (selection)
+        if (gtk_tree_selection_get_selected (selection, model, iter))
+            return TRUE;
     return FALSE;
-    #endif
 }
