@@ -25,7 +25,7 @@ sokoke_spawn_program                (const gchar* command,
 
 gchar*
 sokoke_magic_uri                    (const gchar*    uri,
-                                     MidoriWebList*  search_engines);
+                                     KatzeArray*     search_engines);
 
 void
 sokoke_entry_setup_completion       (GtkEntry*       entry);
@@ -132,6 +132,8 @@ GtkWidget*
 sokoke_action_create_popup_menu_item (GtkAction*     action);
 
 gboolean
-sokoke_gio_supports_http             (void                 );
+sokoke_tree_view_get_selected_iter   (GtkTreeView*   tree_view,
+                                      GtkTreeModel** model,
+                                      GtkTreeIter*   iter);
 
 #endif /* !__SOKOKE_H__ */
